==> freecad_0.13.2935-dfsg.orig.tar.xz: freecad-0.13.2935-dfsg/src/Mod/Image/Gui/Resources/translations/Image_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+93"/>
      <source>Image</source>
      <translation>Зображення</translation>
    </message>
    <message>
      <source>Create image plane...</source>
      <translation>Створити площину зображення...</translation>
    </message>
    <message>
      <source>Create a planar image in the 3D space</source>
      <translation>Створити плоске зображення у 3D-просторі</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation>Створення плоского зображення в 3D просторі</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <source>Image</source>
      <translation>Зображення</translation>
    </message>
    <message>
      <source>Open...</source>
      <translation>Відкрити...</translation>
    </message>
    <message>
      <source>Open image view</source>
      <translation>Відкрити зображення</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+318"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>Невизначений тип кольору простору для перегляду зображень</translation>
    </message>
    <message>
      <source>Image pixel format</source>
      <translation>Формат пікселя зображення</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+77"/>
      <source>&amp;Fit image</source>
      <translation>&amp;Вмістити зображення</translation>
    </message>
    <message>
      <source>Stretch the image to fit the view</source>
      <translation>Розтягнути зображення до розмірів виду</translation>
    </message>
    <message>
      <source>&amp;1:1 scale</source>
      <translation>Масштаб &amp;1:1</translation>
    </message>
    <message>
      <source>Display the image at a 1:1 scale</source>
      <translation>Показати зображення в масштабі 1:1</translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation>&amp;Оригінальний колір</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation>Відтворення зображення в оригінальних кольорах</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation>&amp;Підвищити яскравість кольору</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation>Показувати зображення з підвищеною яскравістю кольорів</translation>
    </message>
    <message>
      <source>Standard</source>
      <translation>Стандартно</translation>
    </message>
    <message>
      <source>Ready...</source>
      <translation>Готово...</translation>
    </message>
    <message>
      <source>grey</source>
      <translation>сірий</translation>
    </message>
    <message>
      <source>zoom</source>
      <translation>масштаб</translation>
    </message>
    <message>
      <source>outside image</source>
      <translation>зовнішнє зображення</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation>Перегляд зображень</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="+106"/>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>Зображення (*.png *.xpm *.jpg *.bmp)</translation>
    </message>
    <message>
      <source>Choose an image file to open</source>
      <translation>Оберіть файл зображення для відкриття</translation>
    </message>
    <message>
      <source>Images</source>
      <translation>Зображення</translation>
    </message>
    <message>
      <source>All files</source>
      <translation>Всі файли</translation>
    </message>
    <message>
      <source>Error open image</source>
      <translation>Помилка відкриття зображення</translation>
    </message>
    <message>
      <source>Could not load the choosen image</source>
      <translation>Не вдалось завантажити обране зображення</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>Зображення</translation>
    </message>
  </context>
</TS>

==> freecad_0.14.3702+dfsg.orig.tar.xz: freecad-0.14.3702/src/Mod/Image/Gui/Resources/translations/Image_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk" sourcelanguage="en">
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+94"/>
      <source>Image</source>
      <translation>Зображення</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create image plane...</source>
      <translation>Створити площину зображення...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a planar image in the 3D space</source>
      <translation>Створити плоске зображення у 3D-просторі</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation type="obsolete">Створення плоского зображення в 3D просторі</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <location line="-44"/>
      <source>Image</source>
      <translation>Зображення</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open...</source>
      <translation>Відкрити...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open image view</source>
      <translation>Відкрити зображення</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+326"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>Невизначений тип кольору простору для перегляду зображень</translation>
    </message>
    <message>
      <location line="-1"/>
      <source>Image pixel format</source>
      <translation>Формат пікселя зображення</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageOrientationDialog</name>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="+14"/>
      <source>Choose orientation</source>
      <translation type="unfinished">Choose orientation</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Image plane</source>
      <translation type="unfinished">Image plane</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>XY-Plane</source>
      <translation type="unfinished">Площина XY</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>XZ-Plane</source>
      <translation type="unfinished">XZ-Plane</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>YZ-Plane</source>
      <translation type="unfinished">YZ-Plane</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Reverse direction</source>
      <translation type="unfinished">Reverse direction</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Offset:</source>
      <translation type="unfinished">Зміщення:</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+77"/>
      <source>&amp;Fit image</source>
      <translation>&amp;Вмістити зображення</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Stretch the image to fit the view</source>
      <translation>Розтягнути зображення до розмірів виду</translation>
    </message>
    <message>
      <location line="+4"/>
      <source>&amp;1:1 scale</source>
      <translation>Масштаб &amp;1:1</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Display the image at a 1:1 scale</source>
      <translation>Показати зображення в масштабі 1:1</translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation type="obsolete">&amp;Оригінальний колір</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation type="obsolete">Відтворення зображення в оригінальних кольорах</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation type="obsolete">&amp;Підвищити яскравість кольору</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation type="obsolete">Показувати зображення з підвищеною яскравістю кольорів</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Standard</source>
      <translation>Стандартно</translation>
    </message>
    <message>
      <location line="+13"/>
      <source>Ready...</source>
      <translation>Готово...</translation>
    </message>
    <message>
      <location line="+375"/>
      <source>grey</source>
      <translation>сірий</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+3"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <source>zoom</source>
      <translation>масштаб</translation>
    </message>
    <message>
      <location line="-62"/>
      <location line="+10"/>
      <location line="+15"/>
      <location line="+16"/>
      <location line="+16"/>
      <source>outside image</source>
      <translation>зовнішнє зображення</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation type="obsolete">Перегляд зображень</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="+117"/>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>Зображення (*.png *.xpm *.jpg *.bmp)</translation>
    </message>
    <message>
      <location line="-99"/>
      <location line="+41"/>
      <location line="+57"/>
      <source>Choose an image file to open</source>
      <translation>Оберіть файл зображення для відкриття</translation>
    </message>
    <message>
      <location line="-105"/>
      <location line="+41"/>
      <source>Images</source>
      <translation>Зображення</translation>
    </message>
    <message>
      <location line="-36"/>
      <location line="+41"/>
      <source>All files</source>
      <translation>Всі файли</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Error open image</source>
      <translation>Помилка відкриття зображення</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Could not load the choosen image</source>
      <translation>Не вдалось завантажити обране зображення</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>Зображення</translation>
    </message>
  </context>
</TS>
